@@ -1,8 +1,10 @@
 # Partial Correlation Coefficients
+#
 # Gilles Pujol 2006
+# Bertrand Iooss 2020 for Semi-Partial Correlation Coefficients
 
 
-estim.pcc <- function(data, i = 1:nrow(data)) {  
+estim.pcc <- function(data, semi, i = 1:nrow(data)) {  
   d <- data[i, ]
   p <- ncol(d) - 1
   pcc <- numeric(p)
@@ -10,13 +12,17 @@ estim.pcc <- function(data, i = 1:nrow(data)) {
     Xtildej.lab <- paste(colnames(d)[c(-1, -j-1)], collapse = "+")
     lm.Y <- lm(formula(paste(colnames(d)[1], "~", Xtildej.lab)), data = d)
     lm.Xj <- lm(formula(paste(colnames(d)[j+1], "~", Xtildej.lab)), data = d)
-    pcc[j] <- cor(d[1] - fitted(lm.Y), d[j+1] - fitted(lm.Xj))
+    if (! semi) {
+      pcc[j] <- cor(d[1] - fitted(lm.Y), d[j+1] - fitted(lm.Xj))
+    } else {
+      pcc[j] <- cor(d[1], d[j+1] - fitted(lm.Xj))
+    }
   }
   pcc
 }
 
 
-pcc <- function(X, y, rank = FALSE, nboot = 0, conf = 0.95) {
+pcc <- function(X, y, rank = FALSE, semi = FALSE, nboot = 0, conf = 0.95) {
   data <- cbind(Y = y, X)
 
   if (rank) {
@@ -26,10 +32,10 @@ pcc <- function(X, y, rank = FALSE, nboot = 0, conf = 0.95) {
   }
   
   if (nboot == 0) {
-    pcc <- data.frame(original = estim.pcc(data))
+    pcc <- data.frame(original = estim.pcc(data, semi))
     rownames(pcc) <- colnames(X)
   } else {
-    boot.pcc <- boot(data, estim.pcc, R = nboot)
+    boot.pcc <- boot(data, estim.pcc, semi = semi, R = nboot)
     pcc <- bootstats(boot.pcc, conf, "basic")
     rownames(pcc) <- colnames(X)
   }
@@ -37,10 +43,18 @@ pcc <- function(X, y, rank = FALSE, nboot = 0, conf = 0.95) {
   out <- list(X = X, y = y, rank = rank, nboot = nboot, conf = conf,
               call = match.call())
   class(out) <- "pcc"
-  if (! rank) {
-    out$PCC <- pcc
+  if (! semi) {
+    if (! rank) {
+      out$PCC <- pcc
+    } else {
+      out$PRCC = pcc
+    }
   } else {
-    out$PRCC = pcc
+    if (! rank) {
+      out$SPCC <- pcc
+    } else {
+      out$SPRCC = pcc
+    }
   }
   return(out)
 }
@@ -54,6 +68,12 @@ print.pcc <- function(x, ...) {
   } else if ("PRCC" %in% names(x)) {
     cat("\nPartial Rank Correlation Coefficients (PRCC):\n")
     print(x$PRCC)
+  } else if ("SPCC" %in% names(x)) {
+    cat("\nSemi-Partial Correlation Coefficients (SPCC):\n")
+    print(x$SPCC)
+  } else if ("SPRCC" %in% names(x)) {
+    cat("\nSemi-Partial Rank Correlation Coefficients (SPRCC):\n")
+    print(x$SPRCC)
   }
 }
 
@@ -61,16 +81,25 @@ print.pcc <- function(x, ...) {
 plot.pcc <- function(x, ylim = c(-1,1), ...) {  
   if ("PCC" %in% names(x)) {
     nodeplot(x$PCC, ylim = ylim, main = "PCC")
-  }else if ("PRCC" %in% names(x)) {
-    nodeplot(x$PRCC, ylim = ylim, main = "PRRC")
+  } else if ("PRCC" %in% names(x)) {
+    nodeplot(x$PRCC, ylim = ylim, main = "PRCC")
+  } else if ("SPCC" %in% names(x)) {
+    nodeplot(x$SPCC, ylim = ylim, main = "SPCC")
+  } else if ("SPRCC" %in% names(x)) {
+    nodeplot(x$SPRCC, ylim = ylim, main = "SPRCC")
   }
 }
 
+
 ggplot.pcc <- function(x, ylim = c(-1,1), ...) {  
   if ("PCC" %in% names(x)) {
     nodeggplot(listx = list(x$PCC), xname = "PCC", ylim = ylim, title = "PCC")
-  }else if ("PRCC" %in% names(x)) {
-    nodeggplot(listx = list(x$PRCC), xname = "PRRCC", ylim = ylim, title = "PCC")
+  } else if ("PRCC" %in% names(x)) {
+    nodeggplot(listx = list(x$PRCC), xname = "PRCC", ylim = ylim, title = "PRCC")
+  } else if ("SPCC" %in% names(x)) {
+    nodeggplot(listx = list(x$SPCC), xname = "SPCC", ylim = ylim, title = "SPCC")
+  } else if ("SPRCC" %in% names(x)) {
+    nodeggplot(listx = list(x$SPRCC), xname = "SPRCC", ylim = ylim, title = "SPRCC")
   }
 }
 
