@@ -42,28 +42,28 @@ src <- function(X, y, rank = FALSE, nboot = 0, conf = 0.95) {
 
 print.src <- function(x, ...) {
   cat("\nCall:\n", deparse(x$call), "\n", sep = "")
-  if ("SRC" %in% names(x)) {
-    cat("\nStandardized Regression Coefficients (SRC):\n")
-    print(x$SRC)
-  } else if ("SRRC" %in% names(x)) {
+  if ("SRRC" %in% names(x)) {
     cat("\nStandardized Rank Regression Coefficients (SRRC):\n")
     print(x$SRRC)
+  } else if ("SRC" %in% names(x)) {
+    cat("\nStandardized Regression Coefficients (SRC):\n")
+    print(x$SRC)
   }
 }
 
 
 plot.src <- function(x, ylim = c(-1,1), ...) {  
-  if ("SRC" %in% names(x)) {
-    nodeplot(x$SRC, ylim = ylim, main = "SRC")
-  } else if ("SRRC" %in% names(x)) {
+  if ("SRRC" %in% names(x)) {
     nodeplot(x$SRRC, ylim = ylim, main = "SRRC")
+  } else if ("SRC" %in% names(x)) {
+    nodeplot(x$SRC, ylim = ylim, main = "SRC")
   }
 }
 
 ggplot.src <- function(x, ylim = c(-1,1), ...) {  
-  if ("SRC" %in% names(x)) {
-    nodeggplot(listx = list(x$SRC), xname = "SRC", ylim = ylim, title = "SRC")
-  } else if ("SRRC" %in% names(x)) {
+  if ("SRRC" %in% names(x)) {
     nodeggplot(listx = list(x$SRRC), xname = "SRRC", ylim = ylim, title = "SRRC")
+  } else if ("SRC" %in% names(x)) {
+    nodeggplot(listx = list(x$SRC), xname = "SRC", ylim = ylim, title = "SRC")
   }
 }
